@@ -2,10 +2,11 @@
 Endpoints handlers
 """
 
-__all__ = ('PointRequestError', 'PointServerError', 'PointClientError', 'PointNotFound404', 'PointThrottled',
+__all__ = ('PointError',
+           'PointRequestError', 'PointServerError', 'PointClientError', 'PointNotFound404', 'PointThrottled',
            'Point', 'ObjectPoint', 'ContractPoint', 'ContractObjectPoint',
            'ListPointMixin', 'RetrievePointMixin', 'ResponseMixin', 'CreatePointMixin', 'UpdatePointMixin',
-           'UploadFilePointMixin', 'ActionPointMixin',
+           'UploadFilePointMixin',
            'ID', 'Contract',
            )
 
@@ -14,7 +15,7 @@ from typing import OrderedDict, Union
 from django.contrib.auth import get_user_model
 from rest_framework.exceptions import ValidationError
 
-from expressmoney import status
+from expressmoney.utils import status
 from expressmoney.api.cache import CacheMixin, CacheObjectMixin
 from expressmoney.api.contract import Contract
 from expressmoney.api.filter import FilterMixin
@@ -82,12 +83,12 @@ class Point:
 
     @log
     def __init__(self,
-                 user: User,
+                 user: Union[int, User],
                  query_params: Union[None, dict] = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
-        self._user = user
+        self._user = user if isinstance(user, User) else User.objects.get(id=user)
         self._cache = None
         self._response = None
         self._is_async = is_async
@@ -152,11 +153,12 @@ class ObjectPoint(Point):
     """For one object endpoints"""
 
     def __init__(self,
-                 user: User,
+                 user: Union[int, User],
                  lookup_field_value: Union[str, int],
                  is_async: bool = False,
                  timeout: tuple = (30, 30),
                  ):
+        user = user if isinstance(user, User) else User.objects.get(id=user)
         self._lookup_field_value = lookup_field_value
         self._point_id.lookup_field_value = lookup_field_value
         super().__init__(user=user, is_async=is_async, timeout=timeout)
@@ -321,7 +323,7 @@ class UpdatePointMixin:
 
 
 class ResponseMixin:
-    """Only for create and update actions"""
+    """Only for create and update"""
 
     _response_contract = None
 
@@ -343,10 +345,3 @@ class UploadFilePointMixin:
 
     def upload_file(self, file, filename: str, file_type: int):
         self._post_file(file, filename, file_type)
-
-
-class ActionPointMixin:
-    """For any type Point"""
-
-    def action(self):
-        self._get()
